import Vue from 'vue';
import { Tag } from './Tag';
declare const _default: import("vue/types/vue").ExtendedVue<Vue, {
    badgeId: number;
    tags: Tag[];
    input: string;
    oldInput: string;
    hiddenInput: string;
    searchResults: Tag[];
    searchSelection: number;
    selectedTag: number;
    isActive: boolean;
    composing: boolean;
    typeaheadTags: Tag[];
}, {
    /**
         * Remove reserved regex characters from a string so that they don't
         * affect search results
         *
         * @param string
         * @returns String
         */
    escapeRegExp(string: string): string;
    /**
         * Add a tag whether from user input or from search results (typeahead)
         *
         * @param ignoreSearchResults
         * @returns void
         */
    tagFromInput(ignoreSearchResults?: boolean): void;
    /**
         * Add a tag from search results when a user clicks on it
         *
         * @param tag
         * @returns void
         */
    tagFromSearchOnClick(tag: Tag): void;
    /**
         * Add the selected tag from the search results.
         * Clear search results.
         * Clear user input.
         *
         * @param tag
         * @return void
         */
    tagFromSearch(tag: Tag): void;
    /**
         * Add/Select a tag
         *
         * @param tag Tag
         * @param force Boolean
         * @returns void | Boolean
         */
    addTag(tag: Tag, force?: boolean): false | undefined;
    /**
         * Remove the last tag in the tags array.
         *
         * @returns void
         */
    removeLastTag(): void;
    /**
         * Remove the selected tag at the specified index.
         *
         * @param index
         * @returns void
         */
    removeTag(index: number): void;
    /**
         * Search the currently entered text in the list of existing tags
         *
         * @returns void | Boolean
         */
    searchTag(): false | undefined;
    /**
         * Perform the actual search
         *
         * @param string searchQuery
         * @return void
         */
    doSearch(searchQuery: string): void;
    /**
         * Hide the typeahead if there's nothing intered into the input field.
         *
         * @returns void
         */
    hideTypeahead(): void;
    /**
         * Select the next search result in typeahead.
         *
         * @returns void
         */
    nextSearchResult(): void;
    /**
         * Select the previous search result in typeahead.
         *
         * @returns void
         */
    prevSearchResult(): void;
    /**
         * Clear/Empty the search results.
         *
         * @reutrns void
         */
    clearSearchResults(returnFocus?: boolean): void;
    /**
         * Clear the list of selected tags.
         *
         * @returns void
         */
    clearTags(): void;
    /**
         * Replace the currently selected tags with the tags from the value.
         *
         * @returns void
         */
    tagsFromValue(): void;
    /**
         * Check if a tag is already selected.
         *
         * @param tag
         * @returns Boolean
         */
    tagSelected(tag: Tag): boolean;
    /**
         * Clear the input.
         *
         * @returns void
         */
    clearInput(): void;
    /**
         * Process all the keyup events.
         *
         * @param e
         * @returns void
         */
    onKeyUp(e: Event): void;
    /**
         * Process all the keydown events.
         *
         * @param e
         * @returns void
         */
    onKeyDown(e: Event): void;
    /**
         * Process the onfocus event.
         *
         * @param e
         * @returns void
         */
    onFocus(e: Event): void;
    /**
         * Process the onClick event.
         *
         * @param e
         * @returns void
         */
    onClick(e: Event): void;
    /**
         * Process the onblur event.
         *
         * @param e
         * @returns void
         */
    onBlur(e: Event): void;
    hiddenInputValue(tag: Tag): string;
    getDisplayField(tag: Tag): string;
    cloneArray(arr: any[]): any[];
}, {
    hideInputField: boolean;
}, {
    elementId: string;
    inputId: string;
    existingTags: Tag[];
    value: Tag[];
    idField: string;
    textField: string;
    displayField: string;
    valueFields: string;
    disabled: boolean;
    typeahead: boolean;
    typeaheadStyle: string;
    typeaheadActivationThreshold: number;
    typeaheadMaxResults: number;
    typeaheadAlwaysShow: boolean;
    typeaheadShowOnFocus: boolean;
    typeaheadHideDiscard: boolean;
    typeaheadUrl: string;
    typeaheadCallback: (str: string) => Promise<Tag[]>;
    placeholder: string;
    discardSearchText: string;
    limit: number;
    hideInputOnLimit: boolean;
    onlyExistingTags: boolean;
    deleteOnBackspace: boolean;
    allowDuplicates: boolean;
    validate: boolean | (() => boolean);
    addTagsOnComma: boolean;
    addTagsOnSpace: boolean;
    addTagsOnBlur: boolean;
    wrapperClass: string;
    sortSearchResults: boolean;
    caseSensitiveTags: boolean;
    beforeAddingTag: (tag: Tag) => boolean;
    beforeRemovingTag: (tag: Tag) => boolean;
}>;
export default _default;
